﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Text;
using System.Globalization;
using System.Diagnostics;
using System.IO;

namespace LocaleInfo
{
    class Program
    {
        static void Main(string[] args)
        {
            List<CultureInfo> missingLocale = new List<CultureInfo>();
            List<CultureInfo> supportedLocale = new List<CultureInfo>();
            foreach (CultureInfo ci in CultureInfoHelper.GetCultures())
            {
                try
                {
                    CultureInfo cultureInfo = CultureInfo.CreateSpecificCulture(ci.Name);
                    CompareInfo compareInfo = cultureInfo.CompareInfo;
                    supportedLocale.Add(ci);
                }
                catch (PlatformNotSupportedException)
                {
                    missingLocale.Add(ci);
                }
            }

            StringBuilder localeInfo = new StringBuilder();
            localeInfo.AppendLine("Locale information current device");
            localeInfo.AppendLine("Missing locale LCID's");
            localeInfo.AppendLine("------------------------------------------------");
            
            int i = 0;
            // print out nlscfg structure
            foreach (CultureInfo locale in missingLocale)
            {
                if(i == 16)
                {
                    localeInfo.AppendLine("");
                    i = 0;
                }

                localeInfo.Append(locale.LCID.ToString("X4") + " ");
                i++;
            }

            localeInfo.AppendLine("");
            localeInfo.AppendLine("------------------------------------------------");
            localeInfo.AppendLine("");
            localeInfo.AppendLine("Supported Locale");

            localeInfo.AppendLine("");
            localeInfo.AppendLine("Total locales installed:" + (supportedLocale.Count + missingLocale.Count));
            localeInfo.AppendLine("Total locales supported:" + supportedLocale.Count);
            localeInfo.AppendLine("Total locales not supported:" + missingLocale.Count);
            localeInfo.AppendLine("");
            localeInfo.AppendLine("----Listing not supported locales-----");
            localeInfo.AppendLine(" ");

            foreach (CultureInfo ci in missingLocale)
            {
                localeInfo.AppendLine(string.Format("0x{0:x2}({1}) : {2}", ci.LCID, ci.Name, ci.EnglishName));
            }

            localeInfo.AppendLine("----END of Listing not supported locales-----");
            
            // Write to file
            StreamWriter writer = new StreamWriter("locale_info.txt");
            writer.WriteLine(localeInfo.ToString());
            
        }
    }
}
